# skip tests known to be problematic in a specific version
%global skip_checks_version 0.1.90
%ifarch %arm
%global skip_checks cairo_cmyk_hack cairo-RGB24 format_with_space srgb_to_lab_u8 xyz_to_lab conversions
%else
%global skip_checks %nil
%endif

%define major 0
%define api 0.1
%define libname %mklibname babl %{api} %{major}
%define girname %mklibname  babl-gir %{api}
%define develname %mklibname -d babl %{api}

%define url_ver %(echo %{version}|cut -d. -f1,2)

Name:           babl
Version:        0.1.108
Release:        %mkrel 1
Summary:        Dynamic, any to any, pixel format conversion library
Group:          System/Libraries
License:        LGPLv3+
URL:            http://www.gegl.org/babl
Source0:        https://download.gimp.org/pub/%{name}/%{url_ver}/%{name}-%{version}.tar.xz
BuildRequires:  librsvg
BuildRequires:  meson
BuildRequires:  pkgconfig(appstream)
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  vala-tools
BuildRequires:  gi-docgen

%description
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.

%package -n     %{libname}
Summary:        A library for %{name}
Group:          System/Libraries
Requires: %name

%description -n %{libname}
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.


%package -n     %{develname}
Summary:        Header files for %{name}
Group:          Development/Libraries
Requires:       %{libname} = :%{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Babl is a dynamic, any to any, pixel format conversion library.
It provides conversions between the myriad of buffer types images
can be stored in. Babl doesn't only help with existing pixel formats,
but also facilitates creation of new and uncommon ones.

GEGL uses babl both for enumeration of pixel formats as well as
conversions between them.

%prep
%setup

%build
%meson -Denable-vapi=true \
%ifarch %{ix86}
	-Denable-mmx=false \
	-Denable-sse=false \
	-Denable-sse2=false \
	-Denable-sse4_1=false \
	-Denable-avx2=false \
	-Denable-f16c=false \
%endif
	-Denable-gir=true
%meson_build

%install
rm -fr %{buildroot} installed-docs
%meson_install

cp -r docs installed-docs
cd installed-docs
rm -f "%{buildroot}/%{develdocdir}"/graphics/meson.build
rm -f "%{buildroot}/%{develdocdir}"/graphics/.gitignore

%files
%{_bindir}/babl

%files -n %{libname}
%{_libdir}/libbabl-%{api}.so.%{major}*
%dir %{_libdir}/babl-%{api}/
%{_libdir}/babl-%{api}/cairo.so
%{_libdir}/babl-%{api}/CIE.so
%{_libdir}/babl-%{api}/double.so
%{_libdir}/babl-%{api}/fast-float.so
%{_libdir}/babl-%{api}/float.so
%{_libdir}/babl-%{api}/gegl-fixups.so
%{_libdir}/babl-%{api}/gggl-lies.so
%{_libdir}/babl-%{api}/gggl.so
%{_libdir}/babl-%{api}/gggl-table-lies.so
%{_libdir}/babl-%{api}/gggl-table.so
%{_libdir}/babl-%{api}/gimp-8bit.so
%{_libdir}/babl-%{api}/grey.so
%{_libdir}/babl-%{api}/half.so
%{_libdir}/babl-%{api}/HCY.so
%{_libdir}/babl-%{api}/HSL.so
%{_libdir}/babl-%{api}/HSV.so
%{_libdir}/babl-%{api}/naive-CMYK.so
%{_libdir}/babl-%{api}/oklab.so
%{_libdir}/babl-%{api}/simple.so
%{_libdir}/babl-%{api}/avx2-int8.so
%{_libdir}/babl-%{api}/sse2-float.so
%{_libdir}/babl-%{api}/sse2-int16.so
%{_libdir}/babl-%{api}/sse2-int8.so
%{_libdir}/babl-%{api}/sse4-int8.so
%{_libdir}/babl-%{api}/sse-half.so
%{_libdir}/babl-%{api}/two-table.so
%{_libdir}/babl-%{api}/u16.so
%{_libdir}/babl-%{api}/u32.so
%{_libdir}/babl-%{api}/ycbcr.so
%{_libdir}/babl-%{api}/x86-64-*.so
%{_libdir}/girepository-1.0/Babl-%{api}.typelib
%{_libdir}/babl-%{api}/formats.so

%files -n %{develname}
%{_libdir}/libbabl-%{api}.so
%{_libdir}/pkgconfig/babl-%{api}.pc
%dir %{_includedir}/babl-%{api}
%dir %{_includedir}/babl-%{api}/babl
%{_includedir}/babl-%{api}/babl/*
%{_datadir}/gir-1.0/Babl-%{api}.gir
%{_datadir}/vala/vapi/babl-0.1.deps
%{_datadir}/vala/vapi/babl-0.1.vapi
%{_docdir}/%{name}-%{api}/

%changelog
* Mon Mar 18 2024 tex - 0.1.108-1pclos2024
- new version

* Tue Nov 07 2023 tex - 0.1.106-1pclos2023
- new version

* Mon Feb 27 2023 tex - 0.1.102-1pclos2023
- new version

* Wed Feb 22 2023 tex - 0.1.100-1pclos2023
- new version

* Mon Nov 14 2022 tex - 0.1.98-1pclos2022
- new version

* Fri Sep 23 2022 tex - 0.1.96-1pclos2022
- new version

* Fri Sep 23 2022 tex - 0.1.92-2pclos2022
- rebuild against updates

* Mon Jun 13 2022 tex - 0.1.92-1pclos2022
- new version


